%==========================================================================
% D13R_1_0_With_U_CBeta_MODEL_v20170228_NEWTFP_v10.m
%==========================================================================
% Date last updated: 28 February 2017

%FINAL

%========================================================================== 

% This script estimates the value of the instataneous consumption betas of a conceptualized mitigation project

% The beta calculated here is an instantaneous beta
    % beta(t) = cov[ln(C_R(t),ln(F(t))] / Var[ln(C_R(t))] 
    % (beta calculations use the log of reference consumption)

% Base model = DICE 2013R except:
     % - no constraint on cumulative industrial emissions (FOSSLIM)
     % - damage function: as in DICE-2007 for the quadratic form or as in
     % Dietz and Asheim 2012

% Use of LHS sampling for the 8 uncertain parameters
    % the distribution for T2XCO2 (climate sensitivity) is truncated from
    % below at +0.75 (cf Hu, Cao and Hong 2012)
    % all distributions are truncated at 0 (from above or below) so that
    % parameters "keep their own sign"

% Adaptation is not modelled

% F_CONS = 0.1 if C and C_R are equal to 2


clear all; close all; clc;
currentfolder = pwd;

%==========================================================================
% INPUTS WHICH CAN BE MODIFIED DIRECTLY BE THE USER:
 % - end date
 % - mode
 % - number of repeats of the model (aa)
 % - number of MC iterations
 % - specification of the damage function: QUADRATIC or DIETZ_ASHEIM (as in
 % Dietz and Asheim)


%==========================================================================   
 % END DATE
    end_date = 2250;
 
 
%==========================================================================
% EMISSIONS CONTROL RATE MIU
 % - Base;                      em_control_rate = 1;
 % - Lim 2 scenario;            em_control_rate = 2;

 em_control_rate = 1;


%==========================================================================
% DAMAGE FUNCTION SPECIFICATION
    QUADRATIC  = 0;  
        % 1 if choice of quadratic function, 0 if use of alternative damage function based on Dietz and Asheim 2012  
        % If QUADRATIC = 1, this means the damage function is as in
        % DICE-2007 (NOT DICE-2013): DAMAGES = YGROSS(t)-YGROSS(t)/(1+A1*TATM(t)+A2*TATM(t)^2);
        
    DIETZ_ASHEIM = 1;  
        % 1 if choice of alternative damage function based on Dietz and Asheim 2012, 0 if quadratic
        % If DIETZ_ASHEIM = 1, this means the damage function is as in
        % Dietz and Asheim 2012: DAMAGES = YGROSS(t)-YGROSS(t)/(1+A1*TATM(t)+A2*TATM(t)^2+(A7*TATM(t))^7);
    
        % Check that the Boolean indicators for the damage function
        % specification are correct
        temp = QUADRATIC + DIETZ_ASHEIM;
        ErrorMessage=['Error: check choice of damage function specification'];
        if ne(temp,1) 
            disp(ErrorMessage);break;
        end;
 

%==========================================================================
% MODE
 % - mode = 1  => Normal (full uncertainty)
 % - mode = 2  => Fixed LHS
 % - mode = 3  => Check mode 
 % - mode = 11 => only CERTAIN = POPASYM (#1) 
 % - mode = 12 => only CERTAIN = T2XCO2 (#2) 
 % - mode = 13 => only CERTAIN = B12 (#3) 
 % - mode = 14 => only CERTAIN = A2 (#4)
 % - mode = 15 => only CERTAIN = A7 (#5) 
 % - mode = 16 => only CERTAIN = GSIGMA1 (#6) 
 % - mode = 17 => only CERTAIN = CPRICE2050 (#7) 
 % - mode = 18 => only CERTAIN = XI (#8) 
 % - mode = 28 => only UNCERTAIN = XI (#8) 

 
  
 
for mode = 28:29
    


%==========================================================================
 
 %-------------------------------------------------------------------------     
 % Number of MC iterations
 
 if mode == 1 || mode == 11 || mode == 12 || mode == 13 || mode == 14 || mode == 15 || mode == 16 || mode == 17 || mode == 18  || mode == 19  || mode == 28 || mode == 29   
    MC         = 50000; % number of MC simulations
    MC_max     = 5; % number of MC simulations which will be written in Excel file

 elseif mode == 2  % Fixed LHS mode
    MC         = 50000; 
    MC_max     = 50000; 
    
  elseif mode == 3 % CHECK mode
    MC         = 1; % number of MC simulations
    MC_max     = 1; 

 
 end;
 

 
%==========================================================================
%==========================================================================
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
% DICE-2013 FIXED PARAMETERS

iterations = MC;
years      = [2010:5:end_date]'; % (NB: model is based on a 5 year time step)
years2     = [2010:5:end_date+5]'; % (NB: model is based on a 5 year time step)
nb_periods = (end_date-2010)/5+1;
count      = 0;
starttime  = cputime;
      
% Time step
TSTEP       = 5;         % Years per period

% Population
POP0        = 6838;      % Initial population (in millions) 
POPADJ      = 0.134490;  % Growth rate to calibrate to 2050 pop projection

% Technology
GAMMA       = 0.300;     % Capital elasticity in production function
DK          = 0.100;     % Depreciation rate on capital per year
Q0          = 66.950;    % 2005 world gross output trill 2005 US dollars   
K0          = 135;       % 2005 value capital trill 2005 US dollars
AL0         = 3.7976214; % Initial level of total factor productivity
DELA        = 0.006;     % Decline rate of technological change per decade
     

GA0_2010    = 0.01523; % const for TFPG (5-year AR(1))
GA0_coeff   = 0.01237;

% Emissions
ELAND0      = 1.53972;   % Carbon emissions from land 2010 [GtC per year]
DELAND      = 0.2;       % Decline rate of land emissions (per period)
E0          = 32.73738;  % Industrial emissions GtC 2010 (GtCO2 per year)
MIU0        = 0.005;     % Initial emissions control rate for base case 2010
SIG0        = 8930*3.666/66.95/1000;% Carbon intensity 2010 (kgCO2 per output 2005 USD 2010)
    SIG0 = round(SIG0*1e9)/1e9;
DSIG        = -0.001;    % Decline rate of decarbonization (per period)

% Carbon cycle
    % Initial conditions
MAT0        = 818.985;          % Initial concentration in atmosphere 2010 (GtC)
MU0         = 1527;             % Initial concentration in upper strata 2010 (GtC)
ML0         = 10010;            % Initial concentration in lower strata 2010 (GtC)
MATEQ       = 588;              % Equilibrium concentration atmosphere
MUEQ        = 1350;             % Equilibrium concentration in upper strata
MLEQ        = 10000;            % Equilibrium concentration in lower strate 
 
% Climate model parameters
FEX0        = -0.06;     % Estimate of 2010 forcings of non-C02 GHG (Wm -2)
FEX1        = 0.62;      % Estimate of 2100 forcings of non-C02 GHG (Wm -2)
TOCEAN0     = 0.0068;    % Initial lower strat. temp change (degrees C) from  1900
TATM0       = 0.830;     % Initial atmpspheric temp change [C] from  1900
C3          = 0.088;     % Transfer coefficient upper to lower stratum
C4          = 0.025;     % Transfer coefficient for lower level
FCO22X      = 3.8;       % Estimated forcings of equilibrium CO2 doubling (Wm -2)

% Climate damage parameters 
A1          = 0;            % Damage intercept

% Abatement cost
EXPCOST2    = 2.8;       % Exponent of control cost function
GBACK       = 0.025;     % Initial cost decline backstop cost per period
MIU_LIMIT2  = 0.8448;    % Emissions control rate in 2050 in the Limit2 scenario of DICE-2013R
LIMMIU      = 1.2;       % Upper limit on control rate after 2150
TNOPOL      = 45;        % Period before which no emissions control base
CPRICE0     = 1.0;       % Initial base carbon price (2005$ per tCO2)
GCPRICE     = 0.02;      % Growth rate of base carbon price per year

% Participation
PERIODFULLPART  = 21;    % Period at which we have full participation
PARTFRACT2010   = 1;     % Fraction of emissions under control regime in 2010
PARTFRACTFULL   = 1;     % Fraction of emissions under control at full time

% Transient TSC correction ("Speed of Adjustment Parameter")
C1 = 0.104;

% Coeffiecient from GtCO2 to GtC
coeff = 5/3.666;
    coeff = round(coeff*1e15)/1e15;

%==========================================================================    
% EMISSIONS CONTROL RATE (from DICE 2008 GAMS script)
    
    if em_control_rate == 1
    
        InputFile = [ currentfolder '\DICE_2013R_1_1_With_U_CBeta_INPUT_MIU.xlsx'];
        MIU = xlsread(InputFile,'MIU'); MIU = MIU(:,2); 
        temp = nb_periods+1;
        MIU = MIU(1:temp);
        MIU = round(MIU*1e9)/1e9;    
        S = xlsread(InputFile,'SAVINGS'); S = S(:,2);  
        S = S(1:temp);
        S = round(S*1e9)/1e9; 
        
        
    elseif em_control_rate == 2     
        
        InputFile = [ currentfolder '\DICE_2013R_1_1_With_U_CBeta_INPUT_MIU_LIM2.xlsx'];
        MIU = xlsread(InputFile,'MIU_LIM2'); MIU = MIU(:,2); 
        temp = nb_periods+1;
        MIU = MIU(1:temp);
        MIU = round(MIU*1e9)/1e9;    
        S = xlsread(InputFile,'SAVINGS_LIM2'); S = S(:,2);  
        S = S(1:temp);
        S = round(S*1e9)/1e9; 

    end;
    
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
% B) STABILITY CONSTRAINTS (from DICE 2008 GAMS script)

K_LOW       = 1;     % Minimum capital (US$ trillions)
MAT_LOW     = 10;    % Maximum carbon concentration in the atmosphere
MU_LOW      = 100;   % Minimum carbon concentration in shallow oceans
ML_LOW      = 1000;  % Minimum carbon concentration in lower oceans
C_LOW       = 2;     % Minimum consumption (US$ trillions)
TOCEAN_HIGH = 20;    % Maximum temperature of lower oceans (degrees C)
TOCEAN_LOW  = -1;    % Minimum temperature of lower oceans (degrees C)
TATM_HIGH   = 40;    % Maximum temperature of atmosphere (degrees C)
CPC_LOW     = 0.01;  % Minimum consumption per capita

%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
% C) INITIALIZATION OF OUTPUT VECTORS AND MATRICES
  
% Uncertain inputs (column vectors)
MC_Nb            = zeros(length(MC),1);
POPASYM_Vect     = zeros(length(MC),1);
T2XCO2_Vect      = zeros(length(MC),1);
B12_Vect         = zeros(length(MC),1);
A2_Vect          = zeros(length(MC),1);
A7_Vect          = zeros(length(MC),1);
GA0_Vect         = zeros(length(MC),1);
GA0_5yrs_Vect    = zeros(length(MC),1);
GSIGMA1_Vect     = zeros(length(MC),1);
CPRICE2050_Vect  = zeros(length(MC),1);
XI_Vect          = zeros(length(MC),1);
TFPG_COMST_Vect  = zeros(length(MC),1);
PBACK_Vect       = zeros(length(MC),1);



            
% Matrices of main outputs (MC x Years)
L_0_MC           = zeros(length(MC), length(years));  % Population (reference)
GA_0_MC          = zeros(length(MC), length(years));  % Growth rate of TFP (per year)
GA_5yrs_0_MC     = zeros(length(MC), length(years));  % Growth rate of TFP (per 5 years)
AL_0_MC          = zeros(length(MC), length(years));  % Level of TFP
GSIG_0_MC        = zeros(length(MC), length(years));  % Change in sigma
SIGMA_0_MC       = zeros(length(MC), length(years));  % CO2eq-emissions / output ratio
PBACKTIME_0_MC   = zeros(length(MC), length(years));
COST1_0_MC       = zeros(length(MC), length(years));
ETREE_0_MC       = zeros(length(MC), length(years));  % Emissions from land use change (reference)
FORCOTH_0_MC     = zeros(length(MC), length(years));  % Exogenous forcing (reference)
MU_R_MC          = zeros(length(MC), length(years));  % Upper ocean carbon concentration (reference)
MU_MC            = zeros(length(MC), length(years));  % Upper ocean carbon concentration (perturbed)
MAT_R_MC         = zeros(length(MC), length(years));  % Atmospheric carbon concentration (reference)
MAT_MC           = zeros(length(MC), length(years));  % Atmospheric carbon concentration (perturbed)
ML_R_MC          = zeros(length(MC), length(years));  % Lower ocean carbon concentration (reference)
ML_MC            = zeros(length(MC), length(years));  % Lower ocean carbon concentration (perturbed)
MATAV_R_MC       = zeros(length(MC), length(years));  % 2-decade lag atmospheric carbon concentration (reference)
MATAV_MC         = zeros(length(MC), length(years));  % 2-decade lag atmospheric carbon concentration (perturbed)
FORC_R_MC        = zeros(length(MC), length(years));  % Total forcing (reference)
FORC_MC          = zeros(length(MC), length(years));  % Total forcing (perturbed)
YGROSS_R_MC      = zeros(length(MC), length(years));  % World product gross of abatement and damages (reference)
YGROSS_MC        = zeros(length(MC), length(years));  % World product gross of abatement and damages (perturbed)
EIND_R_MC        = zeros(length(MC), length(years));  % Industrial emissions (reference)
EIND_MC          = zeros(length(MC), length(years));  % Industrial emissions (perturbed)
E_R_MC           = zeros(length(MC), length(years));  % Total emissions (reference)
E_MC             = zeros(length(MC), length(years));  % Total emissions (perturbed)    
TATM_R_MC        = zeros(length(MC), length(years));  % Atmospheric temperature (reference)
TATM_MC          = zeros(length(MC), length(years));  % Atmospheric temperature (perturbed)
TOCEAN_R_MC      = zeros(length(MC), length(years));  % Atmospheric temperature (reference)
TOCEAN_MC        = zeros(length(MC), length(years));  % Atmospheric temperature (perturbed)
REL_DAMAGES_R_MC = zeros(length(MC), length(years));  % Relative damages (reference)
REL_DAMAGES_MC   = zeros(length(MC), length(years));  % Relative damages (perturbed)
DAMAGES_R_MC     = zeros(length(MC), length(years));  % Damages (reference)
DAMAGES_MC       = zeros(length(MC), length(years));  % Damages (perturbed)
YNET_R_MC        = zeros(length(MC), length(years));  % Output net of damages (reference)
YNET_MC          = zeros(length(MC), length(years));  % Output net of damages (perturbed)
ABATECOST_R_MC   = zeros(length(MC), length(years));  % Abatement costs (reference)
ABATECOST_MC     = zeros(length(MC), length(years));  % Abatement costs (perturbed)
Y_R_MC           = zeros(length(MC), length(years));  % Output net of damages and abatement (reference)
Y_MC             = zeros(length(MC), length(years));  % Output net of damages and abatement (perturbed)
I_R_MC           = zeros(length(MC), length(years));  % Investment (reference)
I_MC             = zeros(length(MC), length(years));  % Investment (perturbed)
C_R_MC           = zeros(length(MC), length(years));  % Consumption (reference)
C_MC             = zeros(length(MC), length(years));  % Consumption (perturbed)
C_Diff_MC        = zeros(length(MC), length(years));  % Difference between perturbed and reference consumption
CperC_R_MC       = zeros(length(MC), length(years));  % Consumption per capita (reference)
CperC_MC         = zeros(length(MC), length(years));  % Consumption per capita (perturbed)
CperC_rate_R_MC  = zeros(length(MC), length(years));  % Rate of growth of consumption per capita (reference)
CperC_rate_MC    = zeros(length(MC), length(years));  % Rate of growth of consumption per capita (perturbed)
K_R_MC           = zeros(length(MC), length(years));  % Capital(reference)
K_MC             = zeros(length(MC), length(years));  % Capital(perturbed)
  
% Matrices for beta calcs)
LOGC_R_MC        = zeros(length(MC), length(years));  % Log of reference consumption
F_DAMAGES_MC     = zeros(length(MC), length(years));  % Mitigation benefits (difference in damages)
F_CONS_MC        = zeros(length(MC), length(years));  % Mitigation benefits (difference in consumption)
LOGF_DAMAGES_MC  = zeros(length(MC), length(years));  % Log of mitigation benefits
LOGF_CONS_MC     = zeros(length(MC), length(years));  % Log of mitigation benefits
  
% Vectors for beta calcs
FDAM_cov_t       = zeros(length(years),1); % covariance of C_R and F
FDAM_var_t       = zeros(length(years),1); % variance of C_R
FDAM_beta_t      = zeros(length(years),1); % instantaneous consumption  
FCONS_cov_t      = zeros(length(years),1); % covariance of C_R and F
FCONS_var_t      = zeros(length(years),1); % variance of C_R
FCONS_beta_t     = zeros(length(years),1); % instantaneous consumption  

EPSILON_MC       = zeros(length(MC), length(years)+1);

%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
% D) DISTRIBUTION OF UNCERTAIN INPUTS + LATIN HYPERCUBE SAMPLING



% Order of variables:
    %1) POPASYM
    %2) T2XCO2
    %3) B12
    %4) A2
    %5) A7
    %6) GSIGMA1
    %7) CPRICE2050
    %8) XI
    %9) TFP_CONST  
    
    
%N.B.: Nordhaus states explicitly in "A Question of Balance": 
%"uncertain variables are distributed independently and with normal
%probability distributions, and we rule out parameters with the wrong sign"
%which means that the above distributions will be truncated at 0.  

%--------------------------------------------------------------------------
%--------------------------------------------------------------------------

%--------------------------------------------------------------------------     
%1) POPASYM = Asymptotic population [millions]
            % Normal distribution with mean 10854 and std deviation 1368
            MU_POPASYM = 10854;
            SIGMA_POPASYM = 1368;
            % For reference only, base value in DICE-2013R: POPASYM = 10500
pd1 = makedist('Normal',MU_POPASYM',SIGMA_POPASYM);
pd1 = truncate(pd1,0,inf); % distribution for POPASYM (=asymptotic population) truncated from below at 0

%--------------------------------------------------------------------------    
%2) T2XCO2  = Equilibrium temp impact of C02 doubling (climate sensitivity)
            % Log-logistic distribution with mean 2.9 and std deviation 1.4
            MU_T2XCO2 = 2.9;
            SIGMA_T2XCO2 = 1.4;
            % Parameters of the log-logistic function:
            LOG_SCALE_T2XCO2 = log(2.6);
            INV_SHAPE_T2XCO2 = 1/4.2; 
            % Source: Dietz and Stern 2014
            % For reference only, base value in DICE-2013R: MEAN_T2XCO2 = 3.2;
         
pd2 = makedist('Loglogistic',LOG_SCALE_T2XCO2',INV_SHAPE_T2XCO2);
pd2 = truncate(pd2,0.75,inf); % distribution for T2XCO2 (=climate sensitivity parameter) truncated from below at 0.75

%--------------------------------------------------------------------------    
%3) B12     = Carbon transfer coefficient
            % Normal distribution with mean 0.06835 and std deviation 0.02020
            MU_B12 = 0.06835;
            SIGMA_B12 = 0.02020;
            % For reference only, base value in DICE-2013R: B12 = 0.088;

pd3 = makedist('Normal',MU_B12',SIGMA_B12);
pd3 = truncate(pd3,0,inf); % distribution for B12 (=transfer coefficient in carbon cycle) truncated from below at 0

%--------------------------------------------------------------------------   
%4) A2      = Damage quadratic term
            % Normal distribution with mean 0.0025 and std deviation 0.0006
            MU_A2 = 0.0025;
            SIGMA_A2 = 0.0006;
            % For reference only, base value in DICE-2013R: A2 = 1.25*0.002131
            % = 0.26638 (incl damage function multiplier to represent missing sectors)   
    
pd4 = makedist('Normal',MU_A2',SIGMA_A2);
pd4 = truncate(pd4,0,inf); % distribution for A2 (=damage quadratic term) truncated from below at 0

%--------------------------------------------------------------------------        
%5) A7      = Coefficient of the term to the power 7 in the damage function term
            % Normal distribution with mean 0.0828 and std deviation 0.0275
            MU_A7 = 0.0828;
            SIGMA_A7 = 0.0275;
            % No reference in DICE-2013R - cf Dietz and Asheim 2012    

pd5 = makedist('Normal',MU_A7',SIGMA_A7);
pd5 = truncate(pd5,0,inf); % distribution for A7 (=coefficient of the damage term to the power 7) truncated from below at 0


%--------------------------------------------------------------------------           
%6) GSIGMA1 = Initial growth of sigma per year
            % Normal distribution with mean -0.0102 and std deviation
            % 0.0064 (IEA data, 5yr rolling average 1971-2011)
            MU_GSIGMA1 = -0.0102;
            SIGMA_GSIGMA1 = 0.0064;
            % For reference only, base value in DICE-2013R: GSIGMA1 = -0.01;  

pd6 = makedist('Normal',MU_GSIGMA1',SIGMA_GSIGMA1);
pd6 = truncate(pd6,-inf,0); % distribution for GSIGMA1 (=initial rate of decarbonization) truncated from above at 0              

%--------------------------------------------------------------------------               
%7) CPRICE2050 = Carbon price in 2050 in the 400ppm  scenario [000$ per tC 2005] 
            % Log-normal distribution with mean of the associated normal distribution = 5.541708 and std deviation of the associated normal distribution = 0.194803
            MU_ASS_CPRICE2050 = 5.541708;  %mean of the associated normal dist
            SIGMA_ASS_CPRICE2050 = 0.194803; %sigma of the associated normal dist
            MU_CPRICE2050 = 260;
            SIGMA_CPRICE2050 = 2614.6^(1/2);
         
pd7 = makedist('Lognormal',MU_ASS_CPRICE2050',SIGMA_ASS_CPRICE2050);
pd7 = truncate(pd7,0,inf); % distribution for CPRICE_2050 (= 2050 carbon price in the 400 ppm scenario) truncated from below at 0
  

%--------------------------------------------------------------------------
%8) XI = Damage multiplier
            % Normal distribution with mean 1 and std deviation 1/3
            MU_XI = 1;
            SIGMA_XI = 0.33;
pd8 = makedist('Normal',MU_XI',SIGMA_XI);


%--------------------------------------------------------------------------
%9) TFP_CONST = Constant in AR(1) process for TFP growth
            % Normal distribution with mean 0.009 and std deviation 0.005
            MU_TFPG_CONST = 0.009;
            SIGMA_TFPG_CONST = 0.005;
pd9 = makedist('Normal',MU_TFPG_CONST',SIGMA_TFPG_CONST);



%--------------------------------------------------------------------------               
DISTR_Vect=[pd1 pd2 pd3 pd4 pd5 pd6 pd7 pd8 pd9];
  
% We assume that the 9 uncertain parameters are independent.      
% The function "lhsdesign" returns an n-by-p matrix, U, containing a Latin hypercube sample of n values on each of p variables. For each column of
% U, the n values are randomly distributed with one from each interval (0,1/n),(1/n,2/n),...,(1-1/n,1)
        
n = MC;                 % # of simulations   
p = 9; 	                % # of uncertain parameters
U = lhsdesign(n,p); 	% LHS samples from uniform distribution


LHS_MC = zeros(n,p);

%--------------------------------------------------------------------------
%--------------------------------------------------------------------------

if mode == 1
    for j=1:p
    LHS_MC(:,j) = icdf(DISTR_Vect(j), U(:,j)); 
    end;  

elseif mode == 2
    InputFile = [ currentfolder '\DICE_2013R_1_1_With_U_CBeta_INPUT_LHS_9.xlsx'];
    LHS_MC = xlsread(InputFile,'LHS_MC','B4:J50003'); 
         

elseif mode == 3
    POPASYM    = MU_POPASYM;
    T2XCO2     = MU_T2XCO2;
    B12        = MU_B12;
    A2         = MU_A2;
    A7         = MU_A7;
    GSIGMA1    = MU_GSIGMA1;
    CPRICE2050 = MU_CPRICE2050;
    TFPG_CONST = MU_TFPG_CONST;
    InputFile = [ currentfolder '\DICE_2013R_1_1_With_U_CBeta_INPUT_XI.xlsx'];
    XI = xlsread(InputFile,'XI');
    XI = XI(1:1);
    
% Considering uncertainty on only one parameter

elseif mode == 11  % Only CERTAIN = POPASYM (#1)   
    
    InputFile = [ currentfolder '\DICE_2013R_1_1_With_U_CBeta_INPUT_LHS_9.xlsx'];
    LHS_MC = xlsread(InputFile,'LHS_MC','B4:J50003'); 
    
    LHS_MC(:,1)  = MU_POPASYM;
    %LHS_MC(:,2) = MU_T2XCO2;
    %LHS_MC(:,3) = MU_B12;
    %LHS_MC(:,4) = MU_A2;
    %LHS_MC(:,5) = MU_A7;
    %LHS_MC(:,6) = MU_GSIGMA1;
    %LHS_MC(:,7) = MU_CPRICE2050; 
    %LHS_MC(:,8) = MU_XI; 
    %LHS_MC(:,9) = MU_TFPG_CONST;
    
elseif mode == 12  % Only CERTAIN = T2XCO2 (#2)   
    
    InputFile = [ currentfolder '\DICE_2013R_1_1_With_U_CBeta_INPUT_LHS_9.xlsx'];
    LHS_MC = xlsread(InputFile,'LHS_MC','B4:J50003');
    
    %LHS_MC(:,1) = MU_POPASYM;
    LHS_MC(:,2)  = MU_T2XCO2;
    %LHS_MC(:,3) = MU_B12;
    %LHS_MC(:,4) = MU_A2;
    %LHS_MC(:,5) = MU_A7;
    %LHS_MC(:,6) = MU_GSIGMA1;
    %LHS_MC(:,7) = MU_CPRICE2050; 
    %LHS_MC(:,8) = MU_XI; 
    %LHS_MC(:,9) = MU_TFPG_CONST;
    

elseif mode == 13  % Only CERTAIN = B12 (#3)   
    
    InputFile = [ currentfolder '\DICE_2013R_1_1_With_U_CBeta_INPUT_LHS_9.xlsx'];
    LHS_MC = xlsread(InputFile,'LHS_MC','B4:J50003');
    
    %LHS_MC(:,1) = MU_POPASYM;
    %LHS_MC(:,2) = MU_T2XCO2;
    LHS_MC(:,3) = MU_B12;
    %LHS_MC(:,4) = MU_A2;
    %LHS_MC(:,5) = MU_A7;
    %LHS_MC(:,6) = MU_GSIGMA1;
    %LHS_MC(:,7) = MU_CPRICE2050; 
    %LHS_MC(:,8) = MU_XI; 
    %LHS_MC(:,9) = MU_TFPG_CONST;
    
    
elseif mode == 14  % Only CERTAIN = A2 (#4)   
    
    InputFile = [ currentfolder '\DICE_2013R_1_1_With_U_CBeta_INPUT_LHS_9.xlsx'];
    LHS_MC = xlsread(InputFile,'LHS_MC','B4:J50003');
    
    %LHS_MC(:,1) = MU_POPASYM;
    %LHS_MC(:,2) = MU_T2XCO2;
    %LHS_MC(:,3) = MU_B12;
    LHS_MC(:,4)  = MU_A2;
    %LHS_MC(:,5) = MU_A7;
    %LHS_MC(:,6) = MU_GSIGMA1;
    %LHS_MC(:,7) = MU_CPRICE2050; 
    %LHS_MC(:,8) = MU_XI;
    %LHS_MC(:,9) = MU_TFPG_CONST;
    
    
elseif mode == 15  % Only CERTAIN = A7 (#5)   
    
    InputFile = [ currentfolder '\DICE_2013R_1_1_With_U_CBeta_INPUT_LHS_9.xlsx'];
    LHS_MC = xlsread(InputFile,'LHS_MC','B4:J50003'); 
    
    %LHS_MC(:,1) = MU_POPASYM;
    %LHS_MC(:,2) = MU_T2XCO2;
    %LHS_MC(:,3) = MU_B12;
    %LHS_MC(:,4) = MU_A2;
    LHS_MC(:,5)  = MU_A7;
    %LHS_MC(:,6) = MU_GSIGMA1;
    %LHS_MC(:,7) = MU_CPRICE2050; 
    %LHS_MC(:,8) = MU_XI;
    %LHS_MC(:,9) = MU_TFPG_CONST;
    

elseif mode == 16  % Only CERTAIN = GSIGMA1 (#6)   
    
    InputFile = [ currentfolder '\DICE_2013R_1_1_With_U_CBeta_INPUT_LHS_9.xlsx'];
    LHS_MC = xlsread(InputFile,'LHS_MC','B4:J50003');
    
    %LHS_MC(:,1) = MU_POPASYM;
    %LHS_MC(:,2) = MU_T2XCO2;
    %LHS_MC(:,3) = MU_B12;
    %LHS_MC(:,4) = MU_A2;
    %LHS_MC(:,5) = MU_A7;
    LHS_MC(:,6) = MU_GSIGMA1;
    %LHS_MC(:,7) = MU_CPRICE2050; 
    %LHS_MC(:,8) = MU_XI;
    %LHS_MC(:,9) = MU_TFPG_CONST;
    
    
elseif mode == 17  % Only CERTAIN = CPRICE2050 (#7)   
    
    InputFile = [ currentfolder '\DICE_2013R_1_1_With_U_CBeta_INPUT_LHS_9.xlsx'];
    LHS_MC = xlsread(InputFile,'LHS_MC','B4:J50003');
    
    %LHS_MC(:,1) = MU_POPASYM;
    %LHS_MC(:,2) = MU_T2XCO2;
    %LHS_MC(:,3) = MU_B12;
    %LHS_MC(:,4) = MU_A2;
    %LHS_MC(:,5) = MU_A7;
    %LHS_MC(:,6) = MU_GSIGMA1;
    LHS_MC(:,7)  = MU_CPRICE2050; 
    %LHS_MC(:,8) = MU_XI;
    %LHS_MC(:,9) = MU_TFPG_CONST;

    
elseif mode == 18  % Only CERTAIN = XI (#8)   
    
    InputFile = [ currentfolder '\DICE_2013R_1_1_With_U_CBeta_INPUT_LHS_9.xlsx'];
    LHS_MC = xlsread(InputFile,'LHS_MC','B4:J50003');
    
    %LHS_MC(:,1) = MU_POPASYM;
    %LHS_MC(:,2) = MU_T2XCO2;
    %LHS_MC(:,3) = MU_B12;
    %LHS_MC(:,4) = MU_A2;
    %LHS_MC(:,5) = MU_A7;
    %LHS_MC(:,6) = MU_GSIGMA1;
    %LHS_MC(:,7) = MU_CPRICE2050; 
    LHS_MC(:,8)  = MU_XI; 
    %LHS_MC(:,9) = MU_TFPG_CONST;

elseif mode == 19  % Only CERTAIN = TFP_CONST (#9)   
    
    InputFile = [ currentfolder '\DICE_2013R_1_1_With_U_CBeta_INPUT_LHS_9.xlsx'];
    LHS_MC = xlsread(InputFile,'LHS_MC','B4:J50003');
    
    %LHS_MC(:,1) = MU_POPASYM;
    %LHS_MC(:,2) = MU_T2XCO2;
    %LHS_MC(:,3) = MU_B12;
    %LHS_MC(:,4) = MU_A2;
    %LHS_MC(:,5) = MU_A7;
    %LHS_MC(:,6) = MU_GSIGMA1;
    %LHS_MC(:,7) = MU_CPRICE2050; 
    %LHS_MC(:,8) = MU_XI; 
    LHS_MC(:,9)  = MU_TFPG_CONST;
    

elseif mode == 28  % Only UNCERTAIN = XI (#8)   
    
    InputFile = [ currentfolder '\DICE_2013R_1_1_With_U_CBeta_INPUT_LHS_9.xlsx'];
    LHS_MC = xlsread(InputFile,'LHS_MC','B4:J50003');
    
    LHS_MC(:,1) = MU_POPASYM;
    LHS_MC(:,2) = MU_T2XCO2;
    LHS_MC(:,3) = MU_B12;
    LHS_MC(:,4) = MU_A2;
    LHS_MC(:,5) = MU_A7;
    LHS_MC(:,6) = MU_GSIGMA1;
    LHS_MC(:,7) = MU_CPRICE2050; 
    %LHS_MC(:,8) = MU_XI;   
    LHS_MC(:,9) = MU_TFPG_CONST;
    
    
    
elseif mode == 29  % Only UNCERTAIN = TFPG_CONST (#9)   
    
    InputFile = [ currentfolder '\DICE_2013R_1_1_With_U_CBeta_INPUT_LHS_9.xlsx'];
    LHS_MC = xlsread(InputFile,'LHS_MC','B4:J50003');
    
    LHS_MC(:,1) = MU_POPASYM;
    LHS_MC(:,2) = MU_T2XCO2;
    LHS_MC(:,3) = MU_B12;
    LHS_MC(:,4) = MU_A2;
    LHS_MC(:,5) = MU_A7;
    LHS_MC(:,6) = MU_GSIGMA1;
    LHS_MC(:,7) = MU_CPRICE2050; 
    LHS_MC(:,8) = MU_XI;   
    %LHS_MC(:,9) = MU_TFPG_CONST;
   
    
end;

    if mode == 2 || mode == 11 || mode == 12 || mode == 13 || mode == 14 || mode == 15 || mode == 16 || mode == 17 || mode == 18 || mode == 19 || mode == 28 || mode == 29
      
        InputFile = [ currentfolder '\DICE_2013R_1_1_With_U_CBeta_INPUT_LHS_9.xlsx'];
        EPSILON_MC = xlsread(InputFile,'EPSILON_MC','B2:AY50001');

    end;


%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
% F) MONTE CARLO SIMULATIONS

for mc = 1:MC;
     
    
    %----------------------------------------------------------------------
    % F0. Print status to screen:
    count = count + 1;
    if fix(mc/100)-mc/100==0;
        clc;
        fprintf(' %-.0f of %-.0f minor iterations.\n',mc,MC); 
        fprintf('    [Est time to completion = %-.1f min]\n',...
        (cputime-starttime)/count*(iterations-count)/60);
    end;
    
    %----------------------------------------------------------------------
    % F1. Take sample from Latin Hypercube Sampling matrix:
        % row    = # of MC iteration
        % column = variable ranking (as defined above) 
      
    POPASYM    = LHS_MC(mc,1);
    T2XCO2     = LHS_MC(mc,2);
    B12        = LHS_MC(mc,3);
    A2         = LHS_MC(mc,4);
    A7         = LHS_MC(mc,5);
    GSIGMA1    = LHS_MC(mc,6);
    CPRICE2050 = LHS_MC(mc,7);
    XI         = LHS_MC(mc,8);
    TFPG_CONST = LHS_MC(mc,9);

   
   
    %----------------------------------------------------------------------
    % Choose EPSILON_Vect
   
    if mode == 1;
   
        %EPSILON     = White noise component of AR(1) process for TFP growth
            % Normal distribution with mean 0 and std deviation 0.03798286
            % (calibrated on historical data)
        MU_GA0WN5 = 0;
        SIGMA_GA0WN5 = 0.06417; % sigma of the 5-yr AR(1) process
        pd9 = makedist('Normal',MU_GA0WN5',SIGMA_GA0WN5);
        EPSILON_Vect = random(pd9,length(years)+1,1)'; 
   
   
    elseif mode == 2 || mode == 11 || mode == 12 || mode == 13 || mode == 14 || mode == 15 || mode == 16 || mode == 17 || mode == 18 || mode == 19 || mode == 28

        EPSILON_Vect = EPSILON_MC(mc,:)'; 
        EPSILON_Vect = round(EPSILON_Vect*1e9)/1e9;
         
        
    elseif mode == 3
   
        % Import EPSILON from Excel file
        InputFile = [ currentfolder '\DICE_2013R_1_1_With_U_CBeta_INPUT_EPSILON.xlsx'];
        EPSILON_Vect = xlsread(InputFile,'EPSILON'); EPSILON_Vect = EPSILON_Vect(:,2); 
        temp = nb_periods+1;
        EPSILON_Vect = EPSILON_Vect(1:temp);
        EPSILON_Vect = round(EPSILON_Vect*1e9)/1e9;
   
    end;
   
  
   %---------------------------------------------------------------------- 
   % Retrieve initial cost of backstop price (PBACK)
   % cf formula in Word document
   % NB: 2050 = period 9
   PBACK = CPRICE2050/((1-GBACK)^(9-1)*MIU_LIMIT2^(EXPCOST2-1));
   PBACK = round(PBACK*1e9)/1e9;
           
   %---------------------------------------------------------------------- 
   % Retrieve TFP_CONST for 5-year AR(1) process
   % cf formula in Word document
   % NB: 2050 = period 9
   
   GA0_const = TFPG_CONST*(GA0_coeff^0 + GA0_coeff^1 + GA0_coeff^2 + GA0_coeff^3 + GA0_coeff^4);
   
   %---------------------------------------------------------------------- 
   % F3. Carbon cycle coefficients matrix
    B23     = 0.00250;          % Carbon cycle transition matrix
    B11     = 1 - B12;          % Carbon cycle transition matrix
    B21     = B12*MATEQ/MUEQ;   % Carbon cycle transition matrix
    B21     = round(B21*1e15)/1e15; % (to avoid discrepancies with the Excel file, as it rounds to the 15th decimal)
    B22     = 1 - B21 - B23;    % Carbon cycle transition matrix
    B32     = B23*MUEQ/MLEQ;    % Carbon cycle transition matrix
    B32     = round(B32*1e15)/1e15; % (to avoid discrepancies with the Excel file, as it rounds to the 15th decimal)
    B33     = 1 - B32;          % Carbon cycle transition matrix
    
    %----------------------------------------------------------------------
    % F4. Initialize output variables paths (column vectors for each MC iteration)  

    % Reference paths which don't depend on emissions
    L_0            = zeros(length(years),1);  % Population
    AL_0           = zeros(length(years),1);  % Level of total factor productivity
    GFACPOP_R      = zeros(length(years),1);  % Growth factor of population
    GA_0           = zeros(length(years),1);  % Growth rate of productivity
    GSIG_0         = zeros(length(years),1);  % Cumulative improvement of energy efficiency
    SIGMA_0        = zeros(length(years),1);  % Co2-eq emissions-output ratio
    FORCOTH_0      = zeros(length(years),1);  % Exogenous forcing
    PARTFRACT_0    = zeros(length(years),1);  % Fraction of emissions in control regime
    PBACKTIME_0    = zeros(length(years),1);  % Backstop price
    COST1_0        = zeros(length(years),1);  % Adjusted cost for backstop
    
    % Reference paths of variables which depend on emissions
    YGROSS_R      = zeros(length(years),1);  % World product gross of abatement and damages
    ETREE_0       = zeros(length(years),1);  % decline rate of land emissions per year = 0.1
    MAT_R         = zeros(length(years),1);  % Atmospheric carbon concentration
    MU_R          = zeros(length(years),1);  % Upper ocean carbon concentration
    ML_R          = zeros(length(years),1);  % Lower ocean carbon concentration
    MATAV_R       = zeros(length(years),1);  % 2-decade lag atmospheric carbon conc.
    FORC_R        = zeros(length(years),1);  % Total forcing 
    TATM_R        = zeros(length(years),1);  % Atmospheric temperature
    TOCEAN_R      = zeros(length(years),1);  % Ocean temperature
    REL_DAMAGES_R = zeros(length(years),1);  % Relative damages
    DAMAGES_R     = zeros(length(years),1);  % Climate damages
    YNET_R        = zeros(length(years),1);  % Output after damages before abatement
    ABATECOST_R   = zeros(length(years),1);  % Cost of emissions reduction
    Y_R           = zeros(length(years),1);  % Output net of damages and abatement
    I_R           = zeros(length(years),1);  % Investment
    C_R           = zeros(length(years),1);  % Consumption
    CperC_R       = zeros(length(years),1);  % Consumption per capita ($000s per year)
    LOGC_R        = zeros(length(years),1);  % Log of reference consumption growth (for beta calcs)
    K_R           = zeros(length(years),1);  % Capital stock
    EIND_R        = zeros(length(years),1);  % Industrial emissions
    E_R           = zeros(length(years),1);  % Total emissions   
        
    % Perturbed paths of variables which depend on emissions  
    YGROSS        = zeros(length(years),1);    % World product gross of abatement and damages
    MAT           = zeros(length(years),1);    % Atmospheric carbon concentration
    MU            = zeros(length(years),1);    % Upper ocean carbon concentration
    ML            = zeros(length(years),1);    % Lower ocean carbon concentration
    MATAV         = zeros(length(years),1);    % 2-decade lag atmospheric carbon conc.
    FORC          = zeros(length(years),1);    % Total forcing 
    TATM          = zeros(length(years),1);    % Atmospheric temperature
    TOCEAN        = zeros(length(years),1);    % Ocean temperature
    REL_DAMAGES   = zeros(length(years),1);    % Relative damages
    DAMAGES       = zeros(length(years),1);    % Climate damages
    YNET          = zeros(length(years),1);    % Output after damages before abatement
    ABATECOST     = zeros(length(years),1);    % Cost of emissions reduction
    MCABATE       = zeros(length(years),1);    % Marginal cost of abatement
    Y             = zeros(length(years),1);    % Output net of damages and abatement
    I             = zeros(length(years),1);    % Investment
    C             = zeros(length(years),1);    % Consumption
    CperC         = zeros(length(years),1);    % Consumption per capita ( in 000s of 2005 $s per year)
    K             = zeros(length(years),1);    % Capital stock
    EIND          = zeros(length(years),1);    % Industrial emissions
    CumEIND       = zeros(length(years),1);    % Cumulative industrial emissions
    E             = zeros(length(years),1);    % Total emissions   
    F_DAMAGES     = zeros(length(years),1);    % Avoided damages
    LOGF_DAMAGES  = zeros(length(years),1);    % Log of avoided damages
    F_CONS        = zeros(length(years),1);    % Avoided damages
    LOGF_CONS     = zeros(length(years),1);    % Log of avoided damages
          

    
    %----------------------------------------------------------------------
    % F6. Calculate reference paths for variables that DO NOT depend on
    % emissions levels (noted NAME_0)

    % Variables
    % L_0         = Population
    % GFACPOP_0   = Growth factor of population
    % GA_0        = Growth rate of productivity
    % AL_0        = Level of total factor productivity
    % GSIG_0      = Cumulative improvement of energy efficiency
    % SIGMA_0     = Co2-eq emissions-output ratio
    % FORCOTH_0   = Exogenous forcing
    % PARTFRACT_0 = Fraction of emissions in control regime
    % ETREE_0     = Emissions from land use change
    % COST1_0     = Adjusted cost for backstop
        
    % Paths initialization:
    L_0(1)          = POP0;
    GA_0(1)         = GA0_2010;
    AL_0(1)         = AL0;
    GSIG_0(1)       = GSIGMA1; 
    SIGMA_0(1)      = SIG0;
    PBACKTIME_0(1)  = PBACK;
    COST1_0(1)      = PBACK*SIGMA_0(1)/EXPCOST2/1000;
    ETREE_0(1)      = ELAND0;
    FORCOTH_0(1)    = FEX0+0.05*(FEX1-FEX0)*(1+1);
    PARTFRACT_0(1)  = PARTFRACT2010;
    
    % Paths calculations:
    t = 1;
    for year = years(1:end)'; t = t + 1;
        L_0(t)= L_0(t-1)*(POPASYM/L_0(t-1))^POPADJ; 
        GA_0(t) = (GA0_const + GA0_coeff*GA_0(t-1) + EPSILON_Vect(t))*exp(-DELA*TSTEP*(t-1));       
        AL_0(t) = AL_0(t-1)/((1-GA_0(t-1))); 
            
        % **GSIG** - first value of GSIG = GSIGMA1 is for year 2 (as GSIG = growth rate)
        GSIG_0(1) = 0;
        GSIG_0(2) = GSIGMA1;
        if t>2
        GSIG_0(t)  = GSIG_0(t-1)*((1+DSIG)^TSTEP);
        end;
        
        SIGMA_0(t) = SIGMA_0(t-1)*(exp(GSIG_0(t)*TSTEP));
        PBACKTIME_0(t) = PBACK*(1-GBACK)^(t-1);
        COST1_0(t)  = PBACKTIME_0(t)*SIGMA_0(t)/EXPCOST2/1000;
        ETREE_0(t) = ELAND0*((1-DELAND)^(t-1)); 
        
        % **FORCOTH** - change after period 19
        if t<19
        FORCOTH_0(t) = FEX0+0.05*(FEX1-FEX0)*(t+1); % as in the Excel model for DICE 2013R on Nordhaus' website
        elseif t>=19
        FORCOTH_0(t) = FEX1;
        end;
                
        PARTFRACT_0(t) = (PARTFRACT2010 + (PARTFRACTFULL-PARTFRACT2010)*(t-1)/PERIODFULLPART)*(t<PERIODFULLPART+1) + PARTFRACTFULL*(t>PERIODFULLPART) ;
    end;
   
     
    %----------------------------------------------------------------------
    % F7. Calculate reference paths for variables that do depend on
    % emissions
    
    % Reference paths initialization:
    K_R(1)         = K0; 
    YGROSS_R(1)    = AL_0(1)*(L_0(1)/1000)^(1-GAMMA)*(K_R(1)^GAMMA);
    EIND_R(1)      = SIGMA_0(1)*(1-MIU(1))*YGROSS_R(1);
    CumEIND_R(1)   = EIND_R(1)*coeff;
    E_R(1)         = EIND_R(1)+ ETREE_0(1);
    MAT_R(1)       = MAT0;
    ML_R(1)        = ML0; 
    MU_R(1)        = MU0; 
    FORC_R(1)      = FCO22X*log((MAT_R(1)/588.000))/log(2) + FORCOTH_0(1); 
    TATM_R(1)      = TATM0; 
    TOCEAN_R(1)    = TOCEAN0; 
    
    % Damages (quadratic or as in Dietz and Asheim, depending on the
    % initial setting - cf lines 35-40) 
    if QUADRATIC == 1
        DAMAGES_R(1) = YGROSS_R(1)-YGROSS_R(1)/(1 + A1*TATM_R(1) + A2*TATM_R(1)^2);
        REL_DAMAGES_R(1) = 1-1/(1 + A1*TATM_R(1) + A2*TATM_R(1)^2);
    elseif DIETZ_ASHEIM == 1
        DAMAGES_R(1) = YGROSS_R(1)*(1-1/((1 + A1*TATM_R(1) + A2*TATM_R(1)^2 + (A7*TATM_R(1))^7)))*((YGROSS_R(1)/YGROSS_R(1))^(XI-1));
        REL_DAMAGES_R(1) = (1-1/((1 + A1*TATM_R(1) + A2*TATM_R(1)^2 + (A7*TATM_R(1))^7)))*((YGROSS_R(1)/YGROSS_R(1))^(XI-1));
    end;
        
    YNET_R(1)      = YGROSS_R(1)-DAMAGES_R(1);
    ABATECOST_R(1) = (PARTFRACT_0(1)^(1-EXPCOST2))*YGROSS_R(1)*COST1_0(1)*(MIU(1)^EXPCOST2);
    Y_R(1)         = YNET_R(1)-ABATECOST_R(1);
    I_R(1)         = S(1)*Y_R(1);
    C_R(1)         = max(C_LOW, Y_R(1)-I_R(1));
    CperC_R(1)     = (C_R(1)/L_0(1))*1000;
    K_R(2)         = max(K_LOW, ((1-DK)^TSTEP)*K_R(1)+TSTEP*I_R(1));
    YGROSS_R(2)    = AL_0(2)*(L_0(2)/1000)^(1-GAMMA)*(K_R(2)^GAMMA);
    EIND_R(2)      = SIGMA_0(2)*(1-MIU(2))*YGROSS_R(2);
    
    % Reference paths calculations:
    t=1;
    for year = years(1:end-1)'; t = t + 1;
        CumEIND_R(t)   = CumEIND_R(t-1) + EIND_R(t)*coeff;
        E_R(t)         = EIND_R(t)+ ETREE_0(t);
        MAT_R(t)       = max(MAT_LOW, B11*MAT_R(t-1) + B21*MU_R(t-1) + E_R(t-1)*coeff); % cf lower bound MAT_LOW
        ML_R(t)        = max(ML_LOW, B23*MU_R(t-1) + B33*ML_R(t-1)); % cf lower bound ML_LOW
        MU_R(t)        = max(MU_LOW, B12*MAT_R(t-1) + B22*MU_R(t-1) + B32*ML_R(t-1)); % cf lower bound MU_LOW
        FORC_R(t)      = FCO22X * (log((MAT_R(t)/588.000))/log(2)) + FORCOTH_0(t); 
        TATM_R(t)      = min(TATM_HIGH, TATM_R(t-1) + C1*(FORC_R(t) - FCO22X/T2XCO2*TATM_R(t-1) - C3*(TATM_R(t-1) - TOCEAN_R(t-1))));
        
        % Upper and lower bounds on atmospheric temperature
        if TOCEAN_R(t-1) + C4*(TATM_R(t-1)-TOCEAN_R(t-1))>=0
        TOCEAN_R(t)    = min(TOCEAN_HIGH, TOCEAN_R(t-1) + C4*(TATM_R(t-1)-TOCEAN_R(t-1)));
            elseif TOCEAN_R(t-1) + C4*(TATM_R(t-1)-TOCEAN_R(t-1))<0
        TOCEAN_R(t)    = max(TOCEAN_LOW, TOCEAN_R(t-1) + C4*(TATM_R(t-1)-TOCEAN_R(t-1)));
        end;
        
        % Damages (quadratic or as in Dietz and Asheim, depending on the
        % initial setting - cf lines 35-40) 
        if QUADRATIC == 1
        DAMAGES_R(t) = YGROSS_R(t)-YGROSS_R(t)/(1 + A1*TATM_R(t) + A2*TATM_R(t)^2);
        REL_DAMAGES_R(t) = 1-1/(1 + A1*TATM_R(t) + A2*TATM_R(t)^2);
            elseif DIETZ_ASHEIM == 1
        DAMAGES_R(t) = YGROSS_R(t)*(1-1/((1 + A1*TATM_R(t) + A2*TATM_R(t)^2 + (A7*TATM_R(t))^7)))*((YGROSS_R(t)/YGROSS_R(1))^(XI-1));
        REL_DAMAGES_R(t) = (1-1/((1 + A1*TATM_R(t) + A2*TATM_R(t)^2 + (A7*TATM_R(t))^7)))*((YGROSS_R(t)/YGROSS_R(1))^(XI-1));
        end;
                       
        YNET_R(t)      = YGROSS_R(t)-DAMAGES_R(t);
        ABATECOST_R(t) = (PARTFRACT_0(t)^(1-EXPCOST2))*YGROSS_R(t)*COST1_0(t)*(MIU(t)^EXPCOST2);
        Y_R(t)         = YNET_R(t)-ABATECOST_R(t);
        I_R(t)         = S(t)*Y_R(t);
        if C_R(t-1) == C_LOW
            C_R(t)= C_LOW;
        else C_R(t) = max(C_LOW, Y_R(t)-I_R(t));
        end;
        CperC_R(t)     = (C_R(t)/L_0(t))*1000;
        K_R(t+1)       = max(K_LOW,((1-DK)^TSTEP)*K_R(t)+TSTEP*I_R(t));
        YGROSS_R(t+1)  = AL_0(t+1)*((L_0(t+1)/1000)^(1-GAMMA))*(K_R(t+1)^GAMMA);
        EIND_R(t+1)    = SIGMA_0(t+1)*(1-MIU(t+1))*YGROSS_R(t+1); 
    end;          
    
    %----------------------------------------------------------------------      
    % F8. Introduction of a mitigation project
    
    % We now introduce a mitigation project: as in the SCC exercise by the EPA (2008), the perturbed emissions' path is modelled as a reduction of 1 unit of
    % emissions in year 2. We then calculate the consequently perturbed paths.
    
    % The following paths do not change
    % L_0         = Population
    % GFACPOP_0   = Growth factor of population
    % GA_0        = Growth rate of productivity
    % AL_0        = Level of total factor productivity
    % GSIG_0      = Cumulative improvement of energy efficiency
    % SIGMA_0     = Co2-eq emissions-output ratio
    % FORCOTH_0   = Exogenous forcing
    % PARTFRACT_0 = Fraction of emissions in control regime
    % ETREE_0     = Emissions from land use change
    % COST1_0     = Adjusted cost for backstop
 
    
    % We now calculate the perturbed paths for the variables which depend on the level of emissions :
        
    % Perturbed paths initialization: 
    K(1)           = K0; 
    YGROSS(1)      = AL_0(1)*(L_0(1)/1000)^(1-GAMMA)*(K(1)^GAMMA);
    EIND(1)        = SIGMA_0(1)*(1-MIU(1))*YGROSS(1);
    
    CumEIND(1)     = EIND(1)*coeff;
    E(1)           = EIND(1)+ ETREE_0(1);
    MAT(1)         = MAT0;
    ML(1)          = ML0; 
    MU(1)          = MU0; 
    FORC(1)        = FCO22X*log((MAT(1)/588.000))/log(2) + FORCOTH_0(1); 
    TATM(1)        = TATM0; 
    TOCEAN(1)      = TOCEAN0; 
    
    % Damages (quadratic or as in Dietz and Asheim, depending on the
    % initial setting - cf lines 35-40)
    if QUADRATIC == 1
    DAMAGES(1) = YGROSS(1)-YGROSS(1)/(1 + A1*TATM(1) + A2*TATM(1)^2);
    REL_DAMAGES(1) = 1-1/(1 + A1*TATM(1) + A2*TATM(1)^2);
        elseif DIETZ_ASHEIM == 1
    DAMAGES(1) = YGROSS(1)*(1-1/((1 + A1*TATM(1) + A2*TATM(1)^2 + (A7*TATM(1))^7)))*((YGROSS(1)/YGROSS(1))^(XI-1));
    REL_DAMAGES(1) = (1-1/((1 + A1*TATM(1) + A2*TATM(1)^2 + (A7*TATM(1))^7)))*((YGROSS(1)/YGROSS(1))^(XI-1));
    end;        
    
    YNET(1)        = YGROSS(1)-DAMAGES(1);
    ABATECOST(1)   = (PARTFRACT_0(1)^(1-EXPCOST2))*YGROSS(1)*COST1_0(1)*(MIU(1)^EXPCOST2);
    Y(1)           = YNET(1)-ABATECOST(1);
    I(1)           = S(1)*Y(1);
    C(1)           = max(C_LOW, Y(1)-I(1));
    CperC(1)       = (C(1)/L_0(1))*1000;
    K(2)           = max(K_LOW, ((1-DK)^TSTEP)*K(1)+TSTEP*I(1));
    YGROSS(2)      = AL_0(2)*(L_0(2)/1000)^(1-GAMMA)*(K(2)^GAMMA);
    
    % Introduction of a mitigation project which reduces industrial emissions in year 2:
    EIND(2)        = (SIGMA_0(2)*(1-MIU(2))*YGROSS(2))-1;
    
    % Perturbed paths calculations:
    t=1;
    for year = years(1:end-1)'; t = t + 1;
        CumEIND(t)     = CumEIND(t-1) + EIND(t)*coeff;
        E(t)           = EIND(t)+ ETREE_0(t);
        MAT(t)         = max(MAT_LOW, B11*MAT(t-1) + B21*MU(t-1) + E(t-1)*coeff); % cf lower bound MAT_LOW
        ML(t)          = max(ML_LOW, B23*MU(t-1) + B33*ML(t-1)); % cf lower bound ML_LOW
        MU(t)          = max(MU_LOW, B12*MAT(t-1) + B22*MU(t-1) + B32*ML(t-1)); % cf lower bound MU_LOW
        FORC(t)        = FCO22X * (log((MAT(t)/588.000))/log(2)) + FORCOTH_0(t); 
        TATM(t)        = min(TATM_HIGH, TATM(t-1) + C1*(FORC(t) - FCO22X/T2XCO2*TATM(t-1) - C3*(TATM(t-1) - TOCEAN(t-1))));
        
        % Upper and lower bounds on atmospheric temperature
        if TOCEAN(t-1) + C4*(TATM(t-1)-TOCEAN(t-1))>=0
        TOCEAN(t)      = min(TOCEAN_HIGH, TOCEAN(t-1) + C4*(TATM(t-1)-TOCEAN(t-1)));
            elseif TOCEAN(t-1) + C4*(TATM(t-1)-TOCEAN(t-1))<0
        TOCEAN(t)      = max(TOCEAN_LOW, TOCEAN(t-1) + C4*(TATM(t-1)-TOCEAN(t-1)));
        end;
          
        % Damages (quadratic or as in Dietz and Asheim, depending on the
        % initial setting - cf lines 35-40)
        if QUADRATIC == 1
        DAMAGES(t) = YGROSS(t)-YGROSS(t)/(1 + A1*TATM(t) + A2*TATM(t)^2);
        REL_DAMAGES(t) = 1-1/(1 + A1*TATM(t) + A2*TATM(t)^2);
            elseif DIETZ_ASHEIM == 1
        DAMAGES(t) = YGROSS(t)*(1-1/((1 + A1*TATM(t) + A2*TATM(t)^2 + (A7*TATM(t))^7)))*((YGROSS(t)/YGROSS(1))^(XI-1));
        REL_DAMAGES(t) = (1-1/((1 + A1*TATM(t) + A2*TATM(t)^2 + (A7*TATM(t))^7)))*((YGROSS(t)/YGROSS(1))^(XI-1));
        end;

        YNET(t)        = YGROSS(t)-DAMAGES(t);
        ABATECOST(t)   = (PARTFRACT_0(t)^(1-EXPCOST2))*YGROSS(t)*COST1_0(t)*(MIU(t)^EXPCOST2);
        Y(t)           = YNET(t)-ABATECOST(t);
        I(t)           = S(t)*Y(t);
        if C(t-1) == C_LOW
            C(t)= C_LOW;
        else C(t) = max(C_LOW, Y(t)-I(t));
        end;
        CperC(t)       = (C(t)/L_0(t))*1000;
        K(t+1)         = max(K_LOW,((1-DK)^TSTEP)*K(t)+TSTEP*I(t));
        YGROSS(t+1)    = AL_0(t+1)*((L_0(t+1)/1000)^(1-GAMMA))*(K(t+1)^GAMMA);
        EIND(t+1)      = SIGMA_0(t+1)*(1-MIU(t+1))*YGROSS(t+1); 
    end;
   
    %----------------------------------------------------------------------
    % F9. Calculate logs of reference consumption and avoided damages for beta calcs 
    
    % - Log of perturbed consumption growth
    LOGC_R(1) = log(C_R(1));
    t=1;
    for year = years(1:end-1)'; t = t + 1;
        LOGC_R(t) = log(C_R(t));
    end;
    
    % - Benefits from mitigation project (F)
    % Benefits from a mitigation project are calculated as the avoided damages
    % i.e. (= - (damages w/out mitigation - damages w/ mitigation)
    % Given that damages are negative, benefits from mitigation should be
    % negative but in order to be able to take logs, we use positive values
    F_DAMAGES(1) = -(DAMAGES(1) - DAMAGES_R(1));
    t=1;
    for year = years(1:end-1)'; t = t + 1;
        F_DAMAGES(t) = -(DAMAGES(t) - DAMAGES_R(t));
    end;
    
    % - Log of avoided damages
    LOGF_DAMAGES(1) = 0; % cf change of emissions in year 2 => F(1) = 0
    LOGF_DAMAGES(2) = 0; % cf change of emissions in year 2 => F(2) = 0
    t=2;
    for year = years(1:end-2)'; t = t + 1;
        LOGF_DAMAGES(t) = log(F_DAMAGES(t));
    end;
    
        % - Benefits from mitigation project (F)
    % Benefits from a mitigation project are calculated as the avoided damages
    % i.e. (= - (damages w/out mitigation - damages w/ mitigation)
    % Given that damages are negative, benefits from mitigation should be
    % negative but in order to be able to take logs, we use positive values
    F_CONS(1) = C(1) - C_R(1);
    t=1;
    for year = years(1:end-1)'; t = t + 1;
        if C(t) == 2 && C_R(t) == 2
            F_CONS(t) = 0.1;
        else F_CONS(t) = C(t) - C_R(t);
        end;
    end;
    
    % - Log of avoided damages
    LOGF_CONS(1) = 0; % cf change of emissions in year 2 => F(1) = 0
    LOGF_CONS(2) = 0; % cf change of emissions in year 2 => F(2) = 0
    t=2;
    for year = years(1:end-2)'; t = t + 1;
        LOGF_CONS(t) = log(F_CONS(t));
    end;
     
        % F9bis. Calculate logs of reference consumption and avoided damages for beta calcs 
    CperC_rate_R(1) = 0;
    CperC_rate(1)   = 0;
    t=1;
    for year = years(1:end-1)'; t = t + 1;
        CperC_rate_R(t) = (CperC_R(t)/CperC_R(t-1))-1;
        CperC_rate(t) = (CperC(t)/CperC(t-1))-1;
    end;
    
    %----------------------------------------------------------------------
    % F10. Fill in MC matrices 
    
    % - for the 9 uncertain inputs (column vectors)
    
    POPASYM_Vect(mc,1)    = POPASYM;
    T2XCO2_Vect(mc,1)     = T2XCO2;
    B12_Vect(mc,1)        = B12;
    A2_Vect(mc,1)         = A2;
    A7_Vect(mc,1)         = A7;
    GSIGMA1_Vect(mc,1)    = GSIGMA1;
    CPRICE2050_Vect(mc,1) = CPRICE2050;
    XI_Vect(mc,1)         = XI;
    TFPG_CONST_Vect(mc,1) = TFPG_CONST;
    PBACK_Vect(mc,1)      = PBACK;

    
       
    % - for the number of MC simulations (colum vectors)  
    MC_Nb(mc) = mc;
       
    % - for variables' paths (MC x Years matrices)  
    
        % -- matrices:
        L_0(end)              = []; % to get rid of the last (t+1)
        L_0_MC(mc,:)          = L_0';
        GA_0(end)             = [];
        GA_0_MC(mc,:)         = GA_0';
        AL_0(end)             = [];
        AL_0_MC(mc,:)         = AL_0';
        GSIG_0(end)           = [];
        GSIG_0_MC(mc,:)       = GSIG_0';
        SIGMA_0(end)          = [];
        SIGMA_0_MC(mc,:)      = SIGMA_0';
        PBACKTIME_0(end)      = [];
        PBACKTIME_0_MC(mc,:)  = PBACKTIME_0';
        COST1_0(end)          = [];
        COST1_0_MC(mc,:)      = COST1_0';
        ETREE_0(end)          = []; % to get rid of the last (t+1)
        ETREE_0_MC(mc,:)      = ETREE_0';
        FORCOTH_0(end)        = []; % to get rid of the last (t+1)
        FORCOTH_0_MC(mc,:)    = FORCOTH_0';
        MAT_R_MC(mc,:)        = MAT_R';
        MAT_MC(mc,:)          = MAT';
        ML_R_MC(mc,:)         = ML_R';
        ML_MC(mc,:)           = ML';
        MU_R_MC(mc,:)         = MU_R'; 
        MU_MC(mc,:)           = MU';
        FORC_R_MC(mc,:)       = FORC_R';
        FORC_MC(mc,:)         = FORC';
        YGROSS_R(end)         = []; % to get rid of the last (t+1)
        YGROSS_R_MC(mc,:)     = YGROSS_R';
        YGROSS(end)           = []; % to get rid of the last (t+1)
        YGROSS_MC(mc,:)       = YGROSS';
        EIND_R(end)            = []; % to get rid of the last (t+1)
        EIND_R_MC(mc,:)        = EIND_R';
        EIND(end)              = []; % to get rid of the last (t+1)
        EIND_MC(mc,:)          = EIND';
        E_R_MC(mc,:)           = E_R';
        E_MC(mc,:)             = E';
        TATM_R_MC(mc,:)        = TATM_R';
        TATM_MC(mc,:)          = TATM';
        TOCEAN_R_MC(mc,:)      = TOCEAN_R';
        TOCEAN_MC(mc,:)        = TOCEAN';
        DAMAGES_R_MC(mc,:)     = DAMAGES_R';
        DAMAGES_MC(mc,:)       = DAMAGES';
        REL_DAMAGES_R_MC(mc,:) = REL_DAMAGES_R';
        REL_DAMAGES_MC(mc,:)   = REL_DAMAGES';
        YNET_R_MC(mc,:)        = YNET_R';
        YNET_MC(mc,:)          = YNET';
        ABATECOST_R_MC(mc,:)   = ABATECOST_R';
        ABATECOST_MC(mc,:)     = ABATECOST';
        Y_R_MC(mc,:)           = Y_R';
        Y_MC(mc,:)             = Y';
        I_R_MC(mc,:)           = I_R';
        I_MC(mc,:)             = I';
        C_R_MC(mc,:)           = C_R';
        C_MC(mc,:)             = C';
        CperC_R_MC(mc,:)       = CperC_R';
        CperC_MC(mc,:)         = CperC';
        CperC_rate_R_MC(mc,:)  = CperC_rate_R';
        CperC_rate_MC(mc,:)    = CperC_rate';
        K_R(end)               = []; % to get rid of the last (t+1)
        K_R_MC(mc,:)           = K_R';
        K(end)                 = []; % to get rid of the last (t+1)
        K_MC(mc,:)             = K';
        
        % -- other (for beta calcs)
        LOGC_R_MC(mc,:)        = LOGC_R';
        F_DAMAGES_MC(mc,:)     = F_DAMAGES';
        LOGF_DAMAGES_MC(mc,:)  = LOGF_DAMAGES';
        F_CONS_MC(mc,:)        = F_CONS';
        LOGF_CONS_MC(mc,:)     = LOGF_CONS';


        EPSILON_MC (mc,:)      = EPSILON_Vect;

        
        
% End of MC simulations loop
   
end;


 MIU(end)              = []; % to get rid of the last (t+1)
 S(end)                = [];

%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
% G. CALCULATIONS FOR INSTANANEOUS BETAS

   t=2;
   for year  = years(1:end-2)'; t = t + 1;
        temp1     = LOGC_R_MC([1:MC],t); % column of LOGC_R_MC matrix corresponding to t
        temp2     = LOGF_DAMAGES_MC([1:MC],t);   % column of LOGF_MC matrix corresponding to t
        temp3     = cov(temp1,temp2);
        FDAM_cov_t(t)  = temp3(1,2);
        FDAM_var_t(t)  = var(temp1);
        FDAM_beta_t(t) = FDAM_cov_t(t)/FDAM_var_t(t);
   end;    
   
   t=2;
   for year  = years(1:end-2)'; t = t + 1;
        temp4     = LOGC_R_MC([1:MC],t); % column of LOGC_R_MC matrix corresponding to t
        temp5     = LOGF_CONS_MC([1:MC],t);   % column of LOGF_MC matrix corresponding to t
        temp6     = cov(temp4,temp5);
        FCONS_cov_t(t)  = temp6(1,2);
        FCONS_var_t(t)  = var(temp4);
        FCONS_beta_t(t) = FCONS_cov_t(t)/FCONS_var_t(t);
   end;    
        
     
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
% H. OUTPUTS


if mode == 1 || mode == 11 || mode == 12 || mode == 13 || mode == 14 || mode == 15 || mode == 16 || mode == 17 || mode == 18 || mode == 19 || mode == 28 || mode == 29
    % Excel file with:
    %Function_DICE_2013R_1_2_new2( aa, QUADRATIC, DIETZ_ASHEIM, MC, MC_max, MU_POPASYM, SIGMA_POPASYM, MU_GSIGMA1, SIGMA_GSIGMA1, MU_T2XCO2, SIGMA_T2XCO2, MU_A2, SIGMA_A2, MU_ASS_CPRICE2050, SIGMA_ASS_CPRICE2050, MU_CPRICE2050, SIGMA_CPRICE2050, MU_B12, SIGMA_B12, MU_A7, SIGMA_A7, MU_XI, SIGMA_XI, PBACK_Vect, MC_Nb, LHS_MC, years, years2, L_0_MC, AL_0_MC, EPSILON_MC, GA_0_MC, FORCOTH_0_MC, YGROSS_R_MC, YGROSS_MC, MU_R_MC, MU_MC, MAT_R_MC, MAT_MC, ML_R_MC, ML_MC, FORC_R_MC, FORC_MC, ETREE_0_MC, EIND_R_MC, EIND_MC, E_R_MC, E_MC, TATM_R_MC, TATM_MC, TOCEAN_R_MC, TOCEAN_MC, DAMAGES_R_MC, DAMAGES_MC, REL_DAMAGES_R_MC, REL_DAMAGES_MC, YNET_R_MC, YNET_MC, ABATECOST_R_MC, ABATECOST_MC, Y_R_MC, Y_MC, C_R_MC, C_MC, CperC_R_MC, CperC_MC, CperC_rate_R_MC, CperC_rate_MC, K_R_MC, K_MC, F_DAMAGES_MC, F_CONS_MC, LOGC_R_MC, LOGF_DAMAGES_MC, LOGF_CONS_MC, FDAM_cov_t, FDAM_var_t, FDAM_beta_t, FCONS_cov_t, FCONS_var_t, FCONS_beta_t)
    Function_DICE_2013R_1_2_newTFP_9( em_control_rate, mode, QUADRATIC, DIETZ_ASHEIM, MC, MC_max, MU_POPASYM, SIGMA_POPASYM, MU_GSIGMA1, SIGMA_GSIGMA1, MU_T2XCO2, SIGMA_T2XCO2, MU_A2, SIGMA_A2, MU_ASS_CPRICE2050, SIGMA_ASS_CPRICE2050, MU_CPRICE2050, SIGMA_CPRICE2050, MU_B12, SIGMA_B12, MU_A7, SIGMA_A7, MU_XI, SIGMA_XI, MU_TFPG_CONST, SIGMA_TFPG_CONST, PBACK_Vect, MC_Nb, LHS_MC, years, years2, L_0_MC, AL_0_MC, EPSILON_MC, GA_0_MC, FORCOTH_0_MC, YGROSS_R_MC, YGROSS_MC, MU_R_MC, MU_MC, MAT_R_MC, MAT_MC, ML_R_MC, ML_MC, FORC_R_MC, FORC_MC, ETREE_0_MC, EIND_R_MC, EIND_MC, E_R_MC, E_MC, TATM_R_MC, TATM_MC, TOCEAN_R_MC, TOCEAN_MC, DAMAGES_R_MC, DAMAGES_MC, REL_DAMAGES_R_MC, REL_DAMAGES_MC, YNET_R_MC, YNET_MC, ABATECOST_R_MC, ABATECOST_MC, Y_R_MC, Y_MC, C_R_MC, C_MC, CperC_R_MC, CperC_MC, CperC_rate_R_MC, CperC_rate_MC, K_R_MC, K_MC, F_DAMAGES_MC, F_CONS_MC, LOGC_R_MC, LOGF_DAMAGES_MC, LOGF_CONS_MC, FDAM_cov_t, FDAM_var_t, FDAM_beta_t, FCONS_cov_t, FCONS_var_t, FCONS_beta_t)
    
elseif mode == 2
    %Function_DICE_2013R_1_2_fixedLHS_9(aa, QUADRATIC, DIETZ_ASHEIM, MC, MC_max, MIU, PBACK_Vect, GA0_5yrs_Vect, MC_Nb, LHS_MC, years, L_0_MC, AL_0_MC, GA_0_MC, FORCOTH_0_MC, YGROSS_R_MC, YGROSS_MC, MU_R_MC, MU_MC, MAT_R_MC, MAT_MC, ML_R_MC, ML_MC, FORC_R_MC, FORC_MC, ETREE_0_MC, EIND_R_MC, EIND_MC, E_R_MC, E_MC, TATM_R_MC, TATM_MC, TOCEAN_R_MC, TOCEAN_MC, DAMAGES_R_MC, DAMAGES_MC, REL_DAMAGES_R_MC, REL_DAMAGES_MC, YNET_R_MC, YNET_MC, ABATECOST_R_MC, ABATECOST_MC, Y_R_MC, Y_MC, C_R_MC, C_MC, CperC_R_MC, CperC_MC, CperC_rate_R_MC, CperC_rate_MC, K_R_MC, K_MC, F_DAMAGES_MC, F_CONS_MC, LOGC_R_MC, LOGF_DAMAGES_MC, LOGF_CONS_MC, FDAM_cov_t, FDAM_var_t, FDAM_beta_t, FCONS_cov_t, FCONS_var_t, FCONS_beta_t);
    Function_DICE_2013R_1_2_newTFP_9( em_control_rate, mode, QUADRATIC, DIETZ_ASHEIM, MC, MC_max, MU_POPASYM, SIGMA_POPASYM, MU_GSIGMA1, SIGMA_GSIGMA1, MU_T2XCO2, SIGMA_T2XCO2, MU_A2, SIGMA_A2, MU_ASS_CPRICE2050, SIGMA_ASS_CPRICE2050, MU_CPRICE2050, SIGMA_CPRICE2050, MU_B12, SIGMA_B12, MU_A7, SIGMA_A7, MU_XI, SIGMA_XI, MU_TFPG_CONST, SIGMA_TFPG_CONST, PBACK_Vect, MC_Nb, LHS_MC, years, years2, L_0_MC, AL_0_MC, EPSILON_MC, GA_0_MC, FORCOTH_0_MC, YGROSS_R_MC, YGROSS_MC, MU_R_MC, MU_MC, MAT_R_MC, MAT_MC, ML_R_MC, ML_MC, FORC_R_MC, FORC_MC, ETREE_0_MC, EIND_R_MC, EIND_MC, E_R_MC, E_MC, TATM_R_MC, TATM_MC, TOCEAN_R_MC, TOCEAN_MC, DAMAGES_R_MC, DAMAGES_MC, REL_DAMAGES_R_MC, REL_DAMAGES_MC, YNET_R_MC, YNET_MC, ABATECOST_R_MC, ABATECOST_MC, Y_R_MC, Y_MC, C_R_MC, C_MC, CperC_R_MC, CperC_MC, CperC_rate_R_MC, CperC_rate_MC, K_R_MC, K_MC, F_DAMAGES_MC, F_CONS_MC, LOGC_R_MC, LOGF_DAMAGES_MC, LOGF_CONS_MC, FDAM_cov_t, FDAM_var_t, FDAM_beta_t, FCONS_cov_t, FCONS_var_t, FCONS_beta_t)
    
    
elseif mode == 3
    % For checking purposes:
    Function_DICE_2013R_1_Cnew( years, MIU, S, EPSILON_Vect, L_0_MC, GA_0_MC, AL_0_MC, GSIG_0_MC, SIGMA_0_MC, PBACKTIME_0_MC, COST1_0_MC, FORCOTH_0_MC, YGROSS_R_MC, YGROSS_MC, ETREE_0_MC, EIND_R_MC, EIND_MC, MAT_R_MC, MAT_MC, FORC_R_MC, FORC_MC, TOCEAN_R_MC, TOCEAN_MC, TATM_R_MC, TATM_MC, DAMAGES_R_MC, DAMAGES_MC, YNET_R_MC, YNET_MC, ABATECOST_R_MC, ABATECOST_MC, Y_R_MC, Y_MC, I_R_MC, I_MC, C_R_MC, C_MC, K_R_MC, K_MC)

end;


% OTHER (old)
%--------------------------------------------------------------------------
% Figure which plots instantaneous betas:
%Function_DICE_2013R_1_3( years, FCONS_beta_t, MC );

%--------------------------------------------------------------------------
% Figure which plots the histograms of each of the uncertain parameters:
%Function_DICE_2013R_1_4( MC, LHS_MC, MU_POPASYM, MU_T2XCO2, MU_B12, MU_A2, MU_A7, MU_GSIGMA1, MU_GA0, MU_CPRICE2050);
%--------------------------------------------------------------------------


%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
% end of mode loop
  end;

  
%--------------------------------------------------------------------------
%------------------------------------------------------------------------- 
% Z. Show when programme has finished running

scriptname = mfilename('fullpath'); 
EndMessage=[scriptname, ' has finished running'];
disp(EndMessage);
